@@ -13,7 +13,10 @@ MAX_VALIDATION_MESSAGES = 1
 class SchemaValidationResult(Exception):
 
     def __init__(self, message: str, results: dict):
-        super(SchemaValidationResult, self).__init__(message)
+        idx = message.find('\n')
+        line = message[0:idx] if idx >= 0 else message
+        line = util.no_acute(line)
+        super(SchemaValidationResult, self).__init__(line)
         self.message = message
         self.results = results if results is not None else {}
 
